u s e   P O E ; 
 u s e   l i b   ' . / l i b / ' ; 
 u s e   M y S e r v e r ; 
 
 M y S e r v e r - > s p a w n ( 
         ' a l i a s '                           = >   ' m y s q l ' , 
         ' p o r t '                             = >   2 3 3 0 6 , 
         ' h o s t n a m e '                     = >   ' l o c a l h o s t ' , 
         ' m a x _ p r o c e s s e s '           = >   4 , 
 ) ; 
 
 P O E : : K e r n e l - > r u n ( ) ; 
 